from .Client import Client
from .Message import Message


# defines a device type
class DeviceType:
    def __init__(self, device_type):
        self.type = device_type

    def on_connect(self, client: Client):
        pass

    def on_message(self, message: Message):
        pass

    def on_disconnect(self, client: Client):
        pass



from __future__ import annotations


# define a packet class
class Packet:
    def __init__(self, *args: bytes, sending: bool = True):
        # byte array
        self.bytes = bytearray()

        # marks if the packet is being used for sending data
        self.__sending = sending

        # go through all of the args and add them
        for arg in args:
            self.bytes.extend(arg)

        # the size of the message in bytes
        self.size = len(self.bytes)

        # if the packet is going to be used for sending add the message size header
        if sending:
            try:
                size = self.size.to_bytes(2, 'big')
            # check if this raises an overflow error if so echo it with some info
            except OverflowError:
                raise OverflowError(" The size of Packet.bytes cannot exceed the size of a 16 bit integer.")

            # if no problems are raised then add the size of the message to the front of self.bytes
            self.bytes[:0] = size

    # used for removing the front two size bytes
    def remove_header(self) -> None:
        # remove first two bytes
        del self.bytes[2:]

    # return the value of sending
    def is_sending(self):
        return self.__sending

    # overload the equality operator in python
    def __eq__(self, other: Packet) -> bool:
        if self.bytes == other.bytes:
            return True
        else:
            return False



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="iot-manager",
    version="0.0.33",
    packages=["iot_manager"],
    author="Dylan Crockett",
    author_email="dylanrcrockett@gmail.com",
    license="MIT",
    description="A management API for connecting and managing Clients via TCP Sockets",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dylancrockett/iot-manager",
    project_urls={
        "Documentation": "https://iotmanager.readthedocs.io/",
        "Source Code": "https://github.com/dylancrockett/iot-manager"
    },
    install_requirements=[
        "gevent"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    python_requires='>=3.6'
)
